@@ -1,7 +1,7 @@
 #include "profdpm.h"
 
 SEXP profBinary(SEXP y, SEXP clust, SEXP param, SEXP method,\
-    SEXP maxiter, SEXP crit, SEXP verbose) {
+    SEXP maxiter, SEXP crit, SEXP verbose, SEXP sampler) {
     SEXP retval, elem, names, class, dim;
     pdpm_t * obj;
     pdpmbm_t * mdl;
@@ -30,6 +30,7 @@ SEXP profBinary(SEXP y, SEXP clust, SEXP param, SEXP method,\
 
     //set flags
     if( LOGICAL(verbose)[0] )    { obj->flags |= FLAG_VERBOSE; }
+    if( LOGICAL(sampler)[0] )    { obj->flags |= FLAG_SAMPLER; }
 
     //set pointers to pdpmbm methods
     obj->move     = &pdpmbm_move;
