@@ -8,7 +8,7 @@
     Jolley, L.B.W. (1961) Summation of Series. pp. 28 ISBN 0-486-60023-8 
 */
 double lfactorial(unsigned int x) {
-    if( x == 0 ) { return 0; }
+    if( x == 0 || x == 1 ) { return 0; }
     return ( LN_SQRT_2PI + (0.5 + x)*log(x) - x );
 }
 
